==> nextcloud-app-bookmarks-1%3A0.16.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/sr.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Обележивач",
    "Add a Bookmark" : "Додај обележивач",
    "Add folder" : "Додај фасциклу",
    "Select" : "Изабери",
    "Deselect" : "Поништи избор",
    "Details" : "Детаљи",
    "Delete" : "Обриши",
    "Saved" : "Сачувано",
    "Date added" : "Датум додавања",
    "Link" : "Веза",
    "Tags" : "Ознаке",
    "Description" : "Опис",
    "No bookmarks here." : "Овде нема обележивача.",
    "Favorites" : "Омиљени",
    "Settings" : "Поставке",
    "Bookmarklet" : "Забележник",
    "Add to {instanceName} " : "Додај на {instanceName} ",
    "Recently added" : "Недавно додато",
    "Most visited" : "Најпосећеније",
    "View mode" : "Режим приказа",
    "List view" : "Приказ листе",
    "RSS Feed" : "РСС довод",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Трајно брише све обележиваче са налога. Нема назад!",
    "Delete all bookmarks" : "Обриши све обележиваче",
    "Open details" : "Отвори детаље",
    "An error occurred while trying to save the bookmark." : "Дошло је до грешке при покушају чувања обележивача.",
    "Error" : "Грешка",
    "Uncategorized" : "Некатегоризовано",
    "Error parsing the import result" : "Грешка при рашчлањивању резултата увоза",
    "Import completed successfully." : "Увоз успешно завршен.",
    "Do you really want to delete all your bookmarks?" : "Заиста желите да обришете све своје обележиваче?",
    "Set tags" : "Постави ознаке",
    "Failed to import one bookmark, because: " : "Неуспешан увоз обележивача, јер:",
    "No file provided for import" : "није дат фајл за увоз",
    "Unsupported file type for import" : "врста фајла за увоз није подржана",
    "A Bookmark manager for Nextcloud" : "Менаџер обележивача за Некстклауд",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Ова апликација омогућава да складиштите и организујете омиљена места на интернету на једном месту, док у исто време можете да их синхронизујете са разним уређајима и прегледачима.\nПогледајте клијенте треће стране излистане овде: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Додај обележивач",
    "This URL is already bookmarked! Overwrite?" : "Овај УРЛ је већ убачен! Пребрисати?",
    "The title of the page" : "Наслов стране",
    "The address of the page" : "Адреса стране",
    "Description of the page" : "Опис стране",
    "Save" : "Сачувај",
    "Previews" : "Прегледи",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Да би приказале прави изглед сајта, Обележивач може користити сервис треће стране да би их генерисале.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Можете се или бесплатно регистровати на <a href=\"http://screeenly.com\">screeenly.com</a> или <a href=\"https://github.com/stefanzweifel/screeenly\">подесити сопствени сервер</a>.",
    "Screenly API URL" : "УРЛ Скринли АПИ-ја",
    "Screenly API key" : "АПИ кључ за Скринли",
    "Bookmarks feed" : "Довод обележивача"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-bookmarks-1%3A1.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/sr.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Обележивач",
    "Add a Bookmark" : "Додај обележивач",
    "Add folder" : "Додај фасциклу",
    "Select" : "Изабери",
    "Deselect" : "Поништи избор",
    "Details" : "Детаљи",
    "Delete" : "Обриши",
    "Saved" : "Сачувано",
    "Date added" : "Датум додавања",
    "Link" : "Веза",
    "Tags" : "Ознаке",
    "Description" : "Опис",
    "No bookmarks here." : "Овде нема обележивача.",
    "Favorites" : "Омиљени",
    "Settings" : "Поставке",
    "Bookmarklet" : "Забележник",
    "Add to {instanceName} " : "Додај на {instanceName} ",
    "Recently added" : "Недавно додато",
    "Most visited" : "Најпосећеније",
    "View mode" : "Режим приказа",
    "List view" : "Приказ листе",
    "RSS Feed" : "РСС довод",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Трајно брише све обележиваче са налога. Нема назад!",
    "Delete all bookmarks" : "Обриши све обележиваче",
    "Open details" : "Отвори детаље",
    "An error occurred while trying to save the bookmark." : "Дошло је до грешке при покушају чувања обележивача.",
    "Error" : "Грешка",
    "Uncategorized" : "Некатегоризовано",
    "Error parsing the import result" : "Грешка при рашчлањивању резултата увоза",
    "Import completed successfully." : "Увоз успешно завршен.",
    "Do you really want to delete all your bookmarks?" : "Заиста желите да обришете све своје обележиваче?",
    "Set tags" : "Постави ознаке",
    "Failed to import one bookmark, because: " : "Неуспешан увоз обележивача, јер:",
    "No file provided for import" : "није дат фајл за увоз",
    "Unsupported file type for import" : "врста фајла за увоз није подржана",
    "A Bookmark manager for Nextcloud" : "Менаџер обележивача за Некстклауд",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Ова апликација омогућава да складиштите и организујете омиљена места на интернету на једном месту, док у исто време можете да их синхронизујете са разним уређајима и прегледачима.\nПогледајте клијенте треће стране излистане овде: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Додај обележивач",
    "This URL is already bookmarked! Overwrite?" : "Овај УРЛ је већ убачен! Пребрисати?",
    "The title of the page" : "Наслов стране",
    "The address of the page" : "Адреса стране",
    "Description of the page" : "Опис стране",
    "Save" : "Сачувај",
    "Previews" : "Прегледи",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Да би приказале прави изглед сајта, Обележивач може користити сервис треће стране да би их генерисале.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Можете се или бесплатно регистровати на <a href=\"http://screeenly.com\">screeenly.com</a> или <a href=\"https://github.com/stefanzweifel/screeenly\">подесити сопствени сервер</a>.",
    "Screeenly API URL" : "УРЛ Screeenly АПИ-ја",
    "Screeenly API key" : "АПИ кључ за Screeenly",
    "Bookmarks feed" : "Довод обележивача"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
